@@ -35,20 +35,22 @@ EXTRA_SRC = {'h5z': [ localpath("lzf/lzf_filter.c"),
               localpath("lzf/lzf/lzf_c.c"),
               localpath("lzf/lzf/lzf_d.c")]}
 
+COMPILER_SETTINGS = {
+   'libraries'      : ['hdf5', 'hdf5_hl'],
+   'include_dirs'   : [localpath('lzf')],
+   'library_dirs'   : [],
+   'define_macros'  : [('H5_USE_16_API', None)]
+}
 
 if sys.platform.startswith('win'):
-    COMPILER_SETTINGS = {
-        'libraries'     : ['h5py_hdf5', 'h5py_hdf5_hl'],
-        'include_dirs'  : [localpath('lzf'), localpath('windows')],
-        'library_dirs'  : [],
-        'define_macros' : [('H5_USE_16_API', None), ('_HDF5USEDLL_', None)] }
-
+    COMPILER_SETTINGS['include_dirs'].append(localpath('windows'))
+    COMPILER_SETTINGS['define_macros'].extend([
+        ('_HDF5USEDLL_', None),
+        ('H5_BUILT_AS_DYNAMIC_LIB', None)
+    ])
 else:
-    COMPILER_SETTINGS = {
-       'libraries'      : ['hdf5', 'hdf5_hl'],
-       'include_dirs'   : [localpath('lzf'), '/opt/local/include', '/usr/local/include'],
-       'library_dirs'   : ['/opt/local/lib', '/usr/local/lib'],
-       'define_macros'  : [('H5_USE_16_API', None)] }
+    COMPILER_SETTINGS['include_dirs'].extend(['/opt/local/include''/usr/local/include'])
+    COMPILER_SETTINGS['library_dirs'].extend(['/opt/local/include''/usr/local/include'])
 
 
 class h5py_build_ext(build_ext):
@@ -145,6 +147,7 @@ class h5py_build_ext(build_ext):
         """ Distutils calls this method to run the command """
 
         from Cython.Build import cythonize
+        import numpy
 
         # Provides all of our build options
         config = self.distribution.get_command_obj('configure')
@@ -176,10 +179,14 @@ DEF MPI4PY_V2 = %(mpi4py_v2)s
 DEF HDF5_VERSION = %(version)s
 DEF SWMR_MIN_HDF5_VERSION = (1,9,178)
 DEF VDS_MIN_HDF5_VERSION = (1,9,233)
+DEF COMPLEX256_SUPPORT = %(complex256_support)s
 """
-                s %= {'mpi': bool(config.mpi),
-                      'mpi4py_v2': bool(v2),
-                      'version': tuple(int(x) for x in config.hdf5_version.split('.'))}
+                s %= {
+                    'mpi': bool(config.mpi),
+                    'mpi4py_v2': bool(v2),
+                    'version': tuple(int(x) for x in config.hdf5_version.split('.')),
+                    'complex256_support': hasattr(numpy, 'complex256')
+                }
                 s = s.encode('utf-8')
                 f.write(s)
 
